package sysinfo

import (
	"encoding/json"
	"strings"
)

type SystemCollector struct{}

func (SystemCollector) Key() string { return "system" }

func (SystemCollector) Collect(c *Context) (json.RawMessage, error) {
	data := map[string]string{
		"timestamp":   c.Now.Format(time.RFC3339),
		"uname":       c.SafeRun("uname", "-a"),
		"lsb_release": c.SafeRun("lsb_release", "-a"),
		"cpuinfo":     c.SafeRead("/proc/cpuinfo"),
		"meminfo":     c.SafeRead("/proc/meminfo"),
		"distro":      "ubuntu",
	}
	serial := strings.TrimSpace(
		c.SafeRun("dmidecode", "-s", "system-serial-number"))
	if serial != "" {
		data["id"] = serial
	}
	return json.Marshal(data)
}
